@@ -1,4 +1,8 @@
 package MooseX::POE::Meta::Trait::Object;
+BEGIN {
+  $MooseX::POE::Meta::Trait::Object::VERSION = '0.211';
+}
+# ABSTRACT: The base class role for MooseX::POE
 
 use Moose::Role;
 use POE::Session;
@@ -96,11 +100,17 @@ no Moose::Role;
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-MooseX::POE::Meta::Trait::Object - The base class role for MooseX::Poe
+MooseX::POE::Meta::Trait::Object - The base class role for MooseX::POE
+
+=head1 VERSION
+
+version 0.211
 
 =head1 SYNOPSIS
 
@@ -133,115 +143,104 @@ MooseX::POE::Meta::Trait::Object - The base class role for MooseX::Poe
 
     no MooseX::Poe;
 
-  
 =head1 DESCRIPTION
 
 MooseX::POE::Meta::TraitObject is a role that is applied to the object base
 classe (usually Moose::Object) that implements a POE::Session.
 
-=head1 DEFAULT METHODS
+=head1 METHODS
 
-=over
-
-=item get_session_id
+=head2 get_session_id
 
 Get the internal POE Session ID, this is useful to hand to other POE aware
 functions.
 
-=item yield
+=head2 yield
 
-=item call
+=head2 call
 
-=item delay
+=head2 delay
 
-=item alarm
+=head2 alarm
 
-=item alarm_add
+=head2 alarm_add
 
-=item delay_add
+=head2 delay_add
 
-=item alarm_set
+=head2 alarm_set
 
-=item alarm_adjust
+=head2 alarm_adjust
 
-=item alarm_remove
+=head2 alarm_remove
 
-=item alarm_remove_all
+=head2 alarm_remove_all
 
-=item delay_set
+=head2 delay_set
 
-=item delay_adjust
+=head2 delay_adjust
 
 A cheap alias for the same POE::Kernel function which will gurantee posting to the object's session.
 
-=item STARTALL
+=head2 STARTALL
 
 Along similar lines to Moose's C<BUILDALL> method which calls all the C<BUILD>
 methods, this function will call all the C<START> methods in your inheritance
 hierarchy automatically when POE first runs your session. (This corresponds to
 the C<_start> event from POE.)
 
-=item STOPALL
+=head2 STOPALL
 
 Along similar lines to C<STARTALL>, but for C<STOP> instead.
 
-=back
+=head2 START
+
+=head2 STOP
+
+=head2 DEFAULT
+
+=head2 CHILD
+
+=head2 PARENT
+
+=head1 DEFAULT METHODS
 
 =head1 PREDEFINED EVENTS 
 
-=over
+=head1 AUTHORS
 
-=item START
+=over 4
 
-=item STOP
+=item *
 
-=item DEFAULT
+Chris Prather <chris@prather.org>
 
-=item CHILD
+=item *
 
-=item PARENT
+Ash Berlin <ash@cpan.org>
+
+=item *
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=item *
+
+Yuval (nothingmuch) Kogman
+
+=item *
+
+Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 AUTHOR
+This software is copyright (c) 2010 by Chris Prather, Ash Berlin, Chris Williams, Yuval Kogman, Torsten Raudssus.
 
-Chris Prather C<< <perigrin@cpan.org> >>
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-Ash Berlin C<< <ash@cpan.org> >>
-
-=head1 CONTRIBUTORS
-
-Torsten Raudssus C<< <torsten@raudssus.de> >>
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2007-2009, Chris Prather C<< <perigrin@cpan.org> >>, Ash Berlin
-C<< <ash@cpan.org> >>. All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+=cut
 
 
-=head1 DISCLAIMER OF WARRANTY
+__END__
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
